@@ -38,6 +38,12 @@ struct OstreeRepo {
   GFile *config_file;
 
   GFile *transaction_lock_path;
+  GMutex txn_stats_lock;
+  guint txn_metadata_objects_total;
+  guint txn_metadata_objects_written;
+  guint txn_content_objects_total;
+  guint txn_content_objects_written;
+  guint64 txn_content_bytes_written;
 
   GMutex cache_lock;
   GPtrArray *cached_meta_indexes;
@@ -59,6 +65,15 @@ GFile *
 _ostree_repo_get_uncompressed_object_cache_path (OstreeRepo       *self,
                                                  const char       *checksum);
 
+GFile *
+_ostree_repo_get_file_object_path (OstreeRepo   *self,
+                                   const char   *checksum);
+
+GFile *
+_ostree_repo_get_object_path (OstreeRepo   *self,
+                              const char   *checksum,
+                              OstreeObjectType type);
+
 gboolean
 _ostree_repo_stage_directory_meta (OstreeRepo   *self,
                                    GFileInfo    *file_info,
