@@ -24,45 +24,33 @@
  * See:
  * https://mail.gnome.org/archives/ostree-list/2012-August/msg00021.html
  *
- * DESIGN:
+ * First, we synchronously fetch all requested refs, and resolve them
+ * to SHA256 commit checksums.
  *
- * Pull refs
- *   For each ref:
- *     Queue scan of commit
+ * Now, there are two threads involved here.  First, there's the
+ * calling thread; we create a temporary #GMainContext, and iterate
+ * it.  This thread performs all HTTP requests.
  *
- * Mainloop:
- *  Process requests, await idle scan
- *  
- * Async queue:
- *  Scan commit
- *   If already cached, recursively scan content
- *   If not, queue fetch
- * 
- *  For each commit:
- *    Verify checksum
- *    Import
- *    Traverse and queue dirtree/dirmeta
- * 
- * Pull dirtrees:
- *  For each dirtree:
- *    Verify checksum
- *    Import
- *    Traverse and queue content/dirtree/dirmeta
+ * The calling thread communicates with the "metadata scanning"
+ * thread.  The purpose of the metadata thread is to avoid blocking
+ * the main thread while reading from the repository.  If a
+ * transaction is interrupted for example, the next run will need to
+ * lstat() each loose object, which could easily be 60000 or more.
  *
- * Pull content meta:
- *  For each content:
- *    Pull meta
- *    If contentcontent needed:
- *      Queue contentcontent
- *    else:
- *      Import
+ * The two threads pass messages back and forth over queues.  The deep
+ * complexity in this code is determining when a pull process is
+ * complete.  When the main thread completes fetching a metadata
+ * object, it passes it over to the metadata thread, which may in turn
+ * queue more work for the main thread.  That in turn may generate
+ * more work for the metadata thread, etc.
  *
- * Pull contentcontent:
- *  For each contentcontent
- *    Verify checksum
- *    Import
- *    
+ * Work completion is presently done via sending special _IDLE message
+ * down the queue; if both threads are idle, the main thread tells the
+ * metadata thread to shut down, and then proceeds to stop iterating
+ * the main context.
  *  
+ * There is still a race condition here.  See
+ * https://bugzilla.gnome.org/show_bug.cgi?id=706456
  */
 
 #include "config.h"
@@ -364,12 +352,11 @@ fetch_uri (OtPullData  *pull_data,
   gboolean ret = FALSE;
   gs_free char *uri_string = NULL;
   gs_unref_object SoupRequest *request = NULL;
-  OstreeFetchUriData fetch_data;
+  OstreeFetchUriData fetch_data = { 0, };
 
   if (g_cancellable_set_error_if_cancelled (cancellable, error))
     return FALSE;
 
-  memset (&fetch_data, 0, sizeof (fetch_data));
   fetch_data.pull_data = pull_data;
 
   uri_string = soup_uri_to_string (uri, FALSE);
@@ -760,23 +747,6 @@ scan_commit_object (OtPullData         *pull_data,
                                  cancellable, error))
     goto out;
   
-  if (pull_data->flags & OSTREE_REPO_PULL_FLAGS_RELATED)
-    {
-      const char *name;
-      gs_unref_variant GVariant *csum_v = NULL;
-
-      related_objects = g_variant_get_child_value (commit, 2);
-      iter = g_variant_iter_new (related_objects);
-
-      while (g_variant_iter_loop (iter, "(&s@ay)", &name, &csum_v))
-        {
-          if (!scan_one_metadata_object (pull_data, ostree_checksum_bytes_peek (csum_v),
-                                         OSTREE_OBJECT_TYPE_COMMIT, recursion_depth + 1,
-                                         cancellable, error))
-            goto out;
-        }
-    }
-
   ret = TRUE;
  out:
   if (iter)
@@ -1184,7 +1154,7 @@ ostree_repo_pull (OstreeRepo               *self,
   gs_free char *branch_rev = NULL;
   gs_free char *remote_mode_str = NULL;
   GSource *queue_src = NULL;
-  OtPullData pull_data_real;
+  OtPullData pull_data_real = { 0, };
   OtPullData *pull_data = &pull_data_real;
   SoupURI *summary_uri = NULL;
   GKeyFile *config = NULL;
@@ -1194,8 +1164,6 @@ ostree_repo_pull (OstreeRepo               *self,
   guint64 start_time;
   guint64 end_time;
 
-  memset (pull_data, 0, sizeof (*pull_data));
-
   pull_data->async_error = error;
   pull_data->main_context = g_main_context_get_thread_default ();
   pull_data->loop = g_main_loop_new (pull_data->main_context, FALSE);
