@@ -207,11 +207,44 @@ ostree_repo_init (OstreeRepo *self)
   g_mutex_init (&self->txn_stats_lock);
 }
 
+/**
+ * ostree_repo_new:
+ * @path: Path to a repository
+ *
+ * Returns: (transfer full): An accessor object for an OSTree repository located at @path
+ */
 OstreeRepo*
 ostree_repo_new (GFile *path)
 {
   return g_object_new (OSTREE_TYPE_REPO, "path", path, NULL);
 }
+
+/**
+ * ostree_repo_new_default:
+ *
+ * If the current working directory appears to be an OSTree
+ * repository, create a new #OstreeRepo object for accessing it.
+ * Otherwise, use the default system repository located at
+ * /ostree/repo.
+ *
+ * Returns: (transfer full): An accessor object for an OSTree repository located at /ostree/repo
+ */
+OstreeRepo*
+ostree_repo_new_default (void)
+{
+  if (g_file_test ("objects", G_FILE_TEST_IS_DIR)
+      && g_file_test ("config", G_FILE_TEST_IS_REGULAR))
+    {
+      gs_unref_object GFile *cwd = g_file_new_for_path (".");
+      return ostree_repo_new (cwd);
+    }
+  else
+    {
+      gs_unref_object GFile *default_repo_path = g_file_new_for_path ("/ostree/repo");
+      return ostree_repo_new (default_repo_path);
+    }
+}
+
 /**
  * ostree_repo_get_config:
  * @self:
@@ -326,7 +359,7 @@ ostree_repo_check (OstreeRepo *self, GError **error)
 
   if (!g_file_test (gs_file_get_path_cached (self->objects_dir), G_FILE_TEST_IS_DIR))
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
                    "Couldn't find objects directory '%s'",
                    gs_file_get_path_cached (self->objects_dir));
       goto out;
@@ -1534,6 +1567,14 @@ create_tree_variant_from_hashes (GHashTable            *file_checksums,
   return serialized_tree;
 }
 
+struct OstreeRepoCommitModifier {
+  volatile gint refcount;
+
+  OstreeRepoCommitModifierFlags flags;
+  OstreeRepoCommitFilter filter;
+  gpointer user_data;
+};
+
 static OstreeRepoCommitFilterResult
 apply_commit_filter (OstreeRepo            *self,
                      OstreeRepoCommitModifier *modifier,
@@ -1627,7 +1668,7 @@ stage_directory_to_mtree_internal (OstreeRepo                  *self,
       if (filter_result == OSTREE_REPO_COMMIT_FILTER_ALLOW)
         {
           g_debug ("Adding: %s", gs_file_get_path_cached (dir));
-          if (!(modifier && modifier->skip_xattrs))
+          if (!(modifier && (modifier->flags & OSTREE_REPO_COMMIT_MODIFIER_FLAGS_SKIP_XATTRS) > 0))
             {
               if (!ostree_get_xattrs_for_file (dir, &xattrs, cancellable, error))
                 goto out;
@@ -1722,7 +1763,7 @@ stage_directory_to_mtree_internal (OstreeRepo                  *self,
                             goto out;
                         }
 
-                      if (!(modifier && modifier->skip_xattrs))
+                      if (!(modifier && (modifier->flags & OSTREE_REPO_COMMIT_MODIFIER_FLAGS_SKIP_XATTRS) > 0))
                         {
                           g_clear_pointer (&xattrs, (GDestroyNotify) g_variant_unref);
                           if (!ostree_get_xattrs_for_file (child, &xattrs, cancellable, error))
@@ -1875,15 +1916,23 @@ ostree_repo_stage_mtree (OstreeRepo           *self,
 
 /**
  * ostree_repo_commit_modifier_new:
+ * @flags: Control options for filter
+ * @commit_filter: (allow-none): Function that can inspect individual files
+ * @user_data: (allow-none): User data
  *
  * Returns: (transfer full): A new commit modifier.
  */
 OstreeRepoCommitModifier *
-ostree_repo_commit_modifier_new (void)
+ostree_repo_commit_modifier_new (OstreeRepoCommitModifierFlags  flags,
+                                 OstreeRepoCommitFilter         commit_filter,
+                                 gpointer                       user_data)
 {
   OstreeRepoCommitModifier *modifier = g_new0 (OstreeRepoCommitModifier, 1);
 
   modifier->refcount = 1;
+  modifier->flags = flags;
+  modifier->filter = commit_filter;
+  modifier->user_data = user_data;
 
   return modifier;
 }
@@ -2361,7 +2410,7 @@ gboolean
 ostree_repo_query_object_storage_size (OstreeRepo           *self,
                                        OstreeObjectType      objtype,
                                        const char           *sha256, 
-                                       gsize                *out_size,
+                                       guint64              *out_size,
                                        GCancellable         *cancellable,
                                        GError              **error)
 {
