@@ -37,6 +37,8 @@ GType ostree_repo_get_type (void);
 
 OstreeRepo* ostree_repo_new (GFile *path);
 
+OstreeRepo* ostree_repo_new_default (void);
+
 gboolean      ostree_repo_check (OstreeRepo  *self, GError **error);
 
 GFile *       ostree_repo_get_path (OstreeRepo  *self);
@@ -173,7 +175,7 @@ gboolean      ostree_repo_write_refspec (OstreeRepo  *self,
                                          const char  *rev,
                                          GError     **error);
 
-gboolean      ostree_repo_list_refs (OstreeRepo       *repo,
+gboolean      ostree_repo_list_refs (OstreeRepo       *self,
                                      const char       *refspec_prefix,
                                      GHashTable      **out_all_refs,
                                      GCancellable     *cancellable,
@@ -216,7 +218,7 @@ gboolean ostree_repo_load_object_stream (OstreeRepo         *self,
 gboolean      ostree_repo_query_object_storage_size (OstreeRepo           *self,
                                                      OstreeObjectType      objtype,
                                                      const char           *sha256, 
-                                                     gsize                *out_size,
+                                                     guint64              *out_size,
                                                      GCancellable         *cancellable,
                                                      GError              **error);
 
@@ -250,24 +252,26 @@ typedef OstreeRepoCommitFilterResult (*OstreeRepoCommitFilter) (OstreeRepo    *r
                                                                 GFileInfo     *file_info,
                                                                 gpointer       user_data);
 
+/**
+ * OstreeRepoCommitModifierFlags:
+ * @OSTREE_REPO_COMMIT_MODIFIER_FLAGS_NONE: No special flags
+ * @OSTREE_REPO_COMMIT_MODIFIER_FLAGS_SKIP_XATTRS: Do not process extended attributes
+ */
+typedef enum {
+  OSTREE_REPO_COMMIT_MODIFIER_FLAGS_NONE = 0,
+  OSTREE_REPO_COMMIT_MODIFIER_FLAGS_SKIP_XATTRS = (1 << 0)
+} OstreeRepoCommitModifierFlags;
+
 /**
  * OstreeRepoCommitModifier:
  *
  * A structure allowing control over commits.
  */
-typedef struct {
-  volatile gint refcount;
+typedef struct OstreeRepoCommitModifier OstreeRepoCommitModifier;
 
-  guint reserved_flags : 31;
-  guint skip_xattrs : 1;
-
-  OstreeRepoCommitFilter filter;
-  gpointer user_data;
-
-  gpointer reserved[3];
-} OstreeRepoCommitModifier;
-
-OstreeRepoCommitModifier *ostree_repo_commit_modifier_new (void);
+OstreeRepoCommitModifier *ostree_repo_commit_modifier_new (OstreeRepoCommitModifierFlags  flags,
+                                                           OstreeRepoCommitFilter         commit_filter,
+                                                           gpointer                       user_data);
 
 GType ostree_repo_commit_modifier_get_type (void);
 
@@ -326,21 +330,15 @@ typedef enum {
   OSTREE_REPO_CHECKOUT_OVERWRITE_UNION_FILES = 1
 } OstreeRepoCheckoutOverwriteMode;
 
-void
-ostree_repo_checkout_tree_async (OstreeRepo               *self,
-                                 OstreeRepoCheckoutMode    mode,
-                                 OstreeRepoCheckoutOverwriteMode    overwrite_mode,
-                                 GFile                    *destination,
-                                 OstreeRepoFile           *source,
-                                 GFileInfo                *source_info,
-                                 GCancellable             *cancellable,
-                                 GAsyncReadyCallback       callback,
-                                 gpointer                  user_data);
-
 gboolean
-ostree_repo_checkout_tree_finish (OstreeRepo               *self,
-                                  GAsyncResult             *result,
-                                  GError                  **error);
+ostree_repo_checkout_tree (OstreeRepo               *self,
+                           OstreeRepoCheckoutMode    mode,
+                           OstreeRepoCheckoutOverwriteMode    overwrite_mode,
+                           GFile                    *destination,
+                           OstreeRepoFile           *source,
+                           GFileInfo                *source_info,
+                           GCancellable             *cancellable,
+                           GError                  **error);
 
 gboolean       ostree_repo_checkout_gc (OstreeRepo        *self,
                                         GCancellable      *cancellable,
@@ -405,7 +403,7 @@ typedef enum {
   OSTREE_REPO_PRUNE_FLAGS_REFS_ONLY
 } OstreeRepoPruneFlags;
 
-gboolean ostree_repo_prune (OstreeRepo        *repo,
+gboolean ostree_repo_prune (OstreeRepo        *self,
                             OstreeRepoPruneFlags   flags,
                             gint               depth,
                             gint              *out_objects_total,
@@ -417,11 +415,9 @@ gboolean ostree_repo_prune (OstreeRepo        *repo,
 /**
  * OstreeRepoPullFlags:
  * @OSTREE_REPO_PULL_FLAGS_NONE: No special options for pull
- * @OSTREE_REPO_PULL_FLAGS_RELATED: Fetch objects referred to by each commit
  */
 typedef enum {
-  OSTREE_REPO_PULL_FLAGS_NONE,
-  OSTREE_REPO_PULL_FLAGS_RELATED
+  OSTREE_REPO_PULL_FLAGS_NONE
 } OstreeRepoPullFlags;
 
 gboolean ostree_repo_pull (OstreeRepo             *self,
