@@ -22,8 +22,6 @@
 
 #pragma once
 
-#include <ostree-checksum-input-stream.h>
-#include <ostree-chain-input-stream.h>
 #include <ostree-core.h>
 #include <ostree-repo.h>
 #include <ostree-mutable-tree.h>
