@@ -31,34 +31,6 @@
 #include "ostree-core.h"
 #include "libgsystem.h"
 
-typedef struct {
-  GError **error;
-  gboolean caught_error;
-
-  GMainLoop *loop;
-} ProcessOneCheckoutData;
-
-static void
-on_checkout_complete (GObject         *object,
-                      GAsyncResult    *result,
-                      gpointer         user_data)
-{
-  ProcessOneCheckoutData *data = user_data;
-  GError *local_error = NULL;
-
-  if (!ostree_repo_checkout_tree_finish ((OstreeRepo*)object, result,
-                                         &local_error))
-    goto out;
-
- out:
-  if (local_error)
-    {
-      data->caught_error = TRUE;
-      g_propagate_error (data->error, local_error);
-    }
-  g_main_loop_quit (data->loop);
-}
-
 
 /**
  * copy_one_config_file:
@@ -247,7 +219,6 @@ checkout_deployment_tree (GFile             *sysroot,
   gs_unref_object GFile *osdeploy_path = NULL;
   gs_unref_object GFile *deploy_target_path = NULL;
   gs_unref_object GFile *deploy_parent = NULL;
-  ProcessOneCheckoutData checkout_data;
 
   root = (OstreeRepoFile*)ostree_repo_file_new_root (repo, csum);
   if (!ostree_repo_file_ensure_resolved (root, error))
@@ -272,19 +243,8 @@ checkout_deployment_tree (GFile             *sysroot,
   g_print ("ostadmin: Creating deployment %s\n",
            gs_file_get_path_cached (deploy_target_path));
 
-  memset (&checkout_data, 0, sizeof (checkout_data));
-  checkout_data.loop = g_main_loop_new (NULL, TRUE);
-  checkout_data.error = error;
-  
-  ostree_repo_checkout_tree_async (repo, 0, 0, deploy_target_path, root,
-                                   file_info, cancellable,
-                                   on_checkout_complete, &checkout_data);
-  
-  g_main_loop_run (checkout_data.loop);
-  
-  g_main_loop_unref (checkout_data.loop);
-  
-  if (checkout_data.caught_error)
+  if (!ostree_repo_checkout_tree (repo, 0, 0, deploy_target_path, root,
+                                  file_info, cancellable, error))
     goto out;
 
   ret = TRUE;
@@ -831,10 +791,16 @@ parse_os_release (const char *contents,
   return ret;
 }
 
+/*
+ * install_deployment_kernel:
+ * 
+ * Write out an entry in /boot/loader/entries for @deployment.
+ */
 static gboolean
 install_deployment_kernel (GFile          *sysroot,
                            int             new_bootversion,
                            OtDeployment   *deployment,
+                           guint           n_deployments,
                            GCancellable   *cancellable,
                            GError        **error)
 
@@ -941,7 +907,7 @@ install_deployment_kernel (GFile          *sysroot,
                                val);
   ot_config_parser_set (bootconfig, "title", title_key);
 
-  version_key = g_strdup_printf ("%d", ot_deployment_get_bootserial (deployment));
+  version_key = g_strdup_printf ("%d", n_deployments - ot_deployment_get_index (deployment));
   ot_config_parser_set (bootconfig, "version", version_key);
 
   linux_relpath = g_file_get_relative_path (bootdir, dest_kernel_path);
@@ -1009,15 +975,12 @@ ot_admin_write_deployments (GFile             *sysroot,
 {
   gboolean ret = FALSE;
   guint i;
-  gs_unref_object OtBootloader *bootloader = NULL;
+  gs_unref_object OtBootloader *bootloader = ot_admin_query_bootloader (sysroot);
 
-  bootloader = ot_admin_query_bootloader (sysroot);
-  if (!bootloader)
-    {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-                   "No known bootloader configuration detected");
-      goto out;
-    }
+  if (bootloader)
+    g_print ("Detected bootloader: %s\n", ot_bootloader_get_name (bootloader));
+  else
+    g_print ("Detected bootloader: (unknown)\n");
 
   if (current_bootversion == new_bootversion)
     {
@@ -1040,7 +1003,8 @@ ot_admin_write_deployments (GFile             *sysroot,
       for (i = 0; i < new_deployments->len; i++)
         {
           OtDeployment *deployment = new_deployments->pdata[i];
-          if (!install_deployment_kernel (sysroot, new_bootversion, deployment,
+          if (!install_deployment_kernel (sysroot, new_bootversion,
+                                          deployment, new_deployments->len,
                                           cancellable, error))
             {
               g_prefix_error (error, "Installing kernel: ");
@@ -1062,9 +1026,12 @@ ot_admin_write_deployments (GFile             *sysroot,
           goto out;
         }
 
-      if (!ot_bootloader_write_config (bootloader, new_bootversion,
-                                       cancellable, error))
-        goto out;
+      if (bootloader && !ot_bootloader_write_config (bootloader, new_bootversion,
+                                                     cancellable, error))
+          {
+            g_prefix_error (error, "Bootloader write config: ");
+            goto out;
+          }
 
       if (!swap_bootloader (sysroot, current_bootversion, new_bootversion,
                             cancellable, error))
