@@ -38,6 +38,7 @@ struct _OtBootloaderInterface
 
   /* virtual functions */
   gboolean             (* query)                  (OtBootloader  *self);
+  const char *         (* get_name)               (OtBootloader  *self);
   gboolean             (* write_config)           (OtBootloader  *self,
                                                    int            bootversion,
                                                    GCancellable  *cancellable,
@@ -48,6 +49,8 @@ GType ot_bootloader_get_type (void) G_GNUC_CONST;
 
 gboolean ot_bootloader_query (OtBootloader *self);
 
+const char *ot_bootloader_get_name (OtBootloader  *self);
+
 gboolean ot_bootloader_write_config (OtBootloader  *self,
                                      int            bootversion,
                                      GCancellable  *cancellable,
