@@ -239,11 +239,10 @@ print_one_argument (OstreeRepo   *repo,
 }
 
 gboolean
-ostree_builtin_ls (int argc, char **argv, GFile *repo_path, GCancellable *cancellable, GError **error)
+ostree_builtin_ls (int argc, char **argv, OstreeRepo *repo, GCancellable *cancellable, GError **error)
 {
   GOptionContext *context;
   gboolean ret = FALSE;
-  gs_unref_object OstreeRepo *repo = NULL;
   const char *rev;
   int i;
   gs_unref_object GFile *root = NULL;
@@ -256,10 +255,6 @@ ostree_builtin_ls (int argc, char **argv, GFile *repo_path, GCancellable *cancel
   if (!g_option_context_parse (context, &argc, &argv, error))
     goto out;
 
-  repo = ostree_repo_new (repo_path);
-  if (!ostree_repo_check (repo, error))
-    goto out;
-
   if (argc <= 1)
     {
       ot_util_usage_error (context, "An COMMIT argument is required", error);
