@@ -154,7 +154,7 @@ idle_print_status (gpointer user_data)
 }
 
 gboolean
-ostree_builtin_pull_local (int argc, char **argv, GFile *repo_path, GCancellable *cancellable, GError **error)
+ostree_builtin_pull_local (int argc, char **argv, OstreeRepo *repo, GCancellable *cancellable, GError **error)
 {
   gboolean ret = FALSE;
   GOptionContext *context;
@@ -173,20 +173,16 @@ ostree_builtin_pull_local (int argc, char **argv, GFile *repo_path, GCancellable
   gs_unref_hashtable GHashTable *commits_to_clone = NULL;
   gs_unref_hashtable GHashTable *source_objects = NULL;
   gs_unref_hashtable GHashTable *objects_to_copy = NULL;
-  OtLocalCloneData datav;
+  OtLocalCloneData datav = { 0, };
   OtLocalCloneData *data = &datav;
 
   context = g_option_context_new ("SRC_REPO [REFS...] -  Copy data from SRC_REPO");
   g_option_context_add_main_entries (context, options, NULL);
 
-  memset (&datav, 0, sizeof (datav));
-
   if (!g_option_context_parse (context, &argc, &argv, error))
     goto out;
 
-  data->dest_repo = ostree_repo_new (repo_path);
-  if (!ostree_repo_check (data->dest_repo, error))
-    goto out;
+  data->dest_repo = g_object_ref (repo);
 
   if (argc < 2)
     {
