@@ -26,21 +26,17 @@
 #include "ostree.h"
 #include "otutil.h"
 
-gboolean opt_related;
-
 static GOptionEntry options[] = {
-  { "related", 0, 0, G_OPTION_ARG_NONE, &opt_related, "Download related commits", NULL },
   { NULL }
 };
 
 gboolean
-ostree_builtin_pull (int argc, char **argv, GFile *repo_path, GCancellable *cancellable, GError **error)
+ostree_builtin_pull (int argc, char **argv, OstreeRepo *repo, GCancellable *cancellable, GError **error)
 {
   GOptionContext *context;
   gboolean ret = FALSE;
   const char *remote;
   OstreeRepoPullFlags pullflags = 0;
-  gs_unref_object OstreeRepo *repo = NULL;
   gs_unref_ptrarray GPtrArray *refs_to_fetch = NULL;
 
   context = g_option_context_new ("REMOTE [BRANCH...] - Download data from remote repository");
@@ -49,10 +45,6 @@ ostree_builtin_pull (int argc, char **argv, GFile *repo_path, GCancellable *canc
   if (!g_option_context_parse (context, &argc, &argv, error))
     goto out;
 
-  repo = ostree_repo_new (repo_path);
-  if (!ostree_repo_check (repo, error))
-    goto out;
-
   if (argc < 2)
     {
       ot_util_usage_error (context, "REMOTE must be specified", error);
@@ -69,9 +61,6 @@ ostree_builtin_pull (int argc, char **argv, GFile *repo_path, GCancellable *canc
       g_ptr_array_add (refs_to_fetch, NULL);
     }
 
-  if (opt_related)
-    pullflags |= OSTREE_REPO_PULL_FLAGS_RELATED;
-
   if (!ostree_repo_pull (repo, remote, refs_to_fetch ? (char**)refs_to_fetch->pdata : NULL,
                     pullflags, cancellable, error))
     goto out;
