@@ -41,13 +41,12 @@ usage_error (GOptionContext *context, const char *message, GError **error)
 }
 
 gboolean
-ostree_builtin_remote (int argc, char **argv, GFile *repo_path, GCancellable *cancellable, GError **error)
+ostree_builtin_remote (int argc, char **argv, OstreeRepo *repo, GCancellable *cancellable, GError **error)
 {
   GOptionContext *context;
   gboolean ret = FALSE;
   const char *op;
   guint i;
-  gs_unref_object OstreeRepo *repo = NULL;
   gs_unref_ptrarray GPtrArray *branches = NULL;
   GKeyFile *config = NULL;
 
@@ -57,10 +56,6 @@ ostree_builtin_remote (int argc, char **argv, GFile *repo_path, GCancellable *ca
   if (!g_option_context_parse (context, &argc, &argv, error))
     goto out;
 
-  repo = ostree_repo_new (repo_path);
-  if (!ostree_repo_check (repo, error))
-    goto out;
-
   if (argc < 2)
     {
       usage_error (context, "OPERATION must be specified", error);
