@@ -39,7 +39,7 @@ typedef struct {
 static GOptionEntry options[] = {
   { "daemonize", 'd', 0, G_OPTION_ARG_NONE, &opt_daemonize, "Fork into background when ready", NULL },
   { "autoexit", 0, 0, G_OPTION_ARG_NONE, &opt_autoexit, "Automatically exit when directory is deleted", NULL },
-  { "port-file", 'p', 0, G_OPTION_ARG_FILENAME, &opt_port_file, "Write port number to PATH", "PATH" },
+  { "port-file", 'p', 0, G_OPTION_ARG_FILENAME, &opt_port_file, "Write port number to PATH (- for standard output)", "PATH" },
   { "force-range-requests", 0, 0, G_OPTION_ARG_NONE, &opt_force_ranges, "Force range requests by only serving half of files", NULL },
   { NULL }
 };
@@ -279,19 +279,17 @@ on_dir_changed (GFileMonitor  *mon,
 }
 
 gboolean
-ostree_builtin_trivial_httpd (int argc, char **argv, GFile *repo_path, GCancellable *cancellable, GError **error)
+ostree_builtin_trivial_httpd (int argc, char **argv, OstreeRepo *repo, GCancellable *cancellable, GError **error)
 {
   gboolean ret = FALSE;
   GOptionContext *context;
   const char *dirpath;
-  OtTrivialHttpd appstruct;
+  OtTrivialHttpd appstruct = { 0, };
   OtTrivialHttpd *app = &appstruct;
   gs_unref_object GFile *dir = NULL;
   gs_unref_object SoupServer *server = NULL;
   gs_unref_object GFileMonitor *dirmon = NULL;
 
-  memset (&appstruct, 0, sizeof (appstruct));
-
   context = g_option_context_new ("[DIR] - Simple webserver");
 
   g_option_context_add_main_entries (context, options, NULL);
@@ -313,7 +311,9 @@ ostree_builtin_trivial_httpd (int argc, char **argv, GFile *repo_path, GCancella
   if (opt_port_file)
     {
       gs_free char *portstr = g_strdup_printf ("%u\n", soup_server_get_port (server));
-      if (!g_file_set_contents (opt_port_file, portstr, strlen (portstr), error))
+      if (g_strcmp0 ("-", opt_port_file) == 0)
+        fputs (portstr, stdout); // not g_print - this must go to stdout, not a handler
+      else if (!g_file_set_contents (opt_port_file, portstr, strlen (portstr), error))
         goto out;
     }
   soup_server_run_async (server);
@@ -334,12 +334,31 @@ ostree_builtin_trivial_httpd (int argc, char **argv, GFile *repo_path, GCancella
           _exit (0);
         }
       /* Child, continue */
+      /* Daemonising: close stdout/stderr so $() et al work on us */
+      fclose (stdout);
+      fclose (stdin);
     }
 
   app->running = TRUE;
   if (opt_autoexit)
     {
-      dirmon = g_file_monitor_directory (app->root, 0, cancellable, error);
+      gboolean is_symlink = FALSE;
+      gs_unref_object GFileInfo *info = NULL;
+
+      info = g_file_query_info (app->root,
+                               G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK,
+                               G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
+                               cancellable, error);
+      if (!info)
+        goto out;
+
+      is_symlink = g_file_info_get_is_symlink (info);
+
+      if (is_symlink)
+        dirmon = g_file_monitor_file (app->root, 0, cancellable, error);
+      else
+        dirmon = g_file_monitor_directory (app->root, 0, cancellable, error);
+
       if (!dirmon)
         goto out;
       g_signal_connect (dirmon, "changed", G_CALLBACK (on_dir_changed), app);
